// {{{ copyright

/********************************************************************
 *
 * $Id: FileChooser.java,v 1.6 2000/07/05 14:07:43 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.apps.qflog;

// {{{ imports

import java.io.File;

import java.awt.Component;
import javax.swing.JFileChooser;
import javax.swing.filechooser.FileFilter;

import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;

// }}}

/**
 * This FileChooser implementation for log files includes convenience methods
 * to open a FileChooser and get the chosen File.
 */
public class FileChooser extends JFileChooser
{
    // {{{ variables

    /**
     * Whether to trace method calls.
     */
    public static boolean TRACE = true;
    /**
     * The Logger used for logging.
     */
    private static Logger logger = new Logger (FileChooser.class);

    /**
     * The FileFilter for log files.
     */
    private static LSFileFilter ffls = new LSFileFilter (".lsv");

    // }}}

    // {{{ constructor

    /**
     * Create a new FileChooser.
     */
    public FileChooser ()
    {
    }

    // }}}

    // {{{ openLog

    /**
     * Bring up a FileChooser to open a logfile.
     *
     * @param   parent  The parent Component for the FileChooser.
     *
     * @return  The chosen File.
     */
    public static File openLog(Component parent)
    {
        JFileChooser fc = new JFileChooser (new File ("."));

        fc.setApproveButtonText
            (App.getResources().getString("dialog.open.name"));
        fc.setApproveButtonMnemonic
            (App.getResources().getString("dialog.open.mnemonic").charAt(0));

        fc.setFileFilter(ffls);

        if (fc.showDialog(parent, null) == JFileChooser.APPROVE_OPTION) {
            return fc.getSelectedFile();
        }
        return null;
    }

    // }}}
    // {{{ saveLogAs

    /**
     * Bring up a FileChooser to save a logfile.
     *
     * @param   parent  The parent Component for the FileChooser.
     *
     * @return  The chosen File.
     */
    public static File saveLogAs(Component parent)
    {
        return saveAs(parent, ffls);
    }

    // }}}

    // {{{ saveAs

    /**
     * Bring up a FileChooser to save a logfile.
     *
     * @param   parent  The parent Component for the FileChooser.
     *
     * @return  The chosen File.
     */
    private static File saveAs(Component parent, FileFilter filter)
    {
        JFileChooser fc = new JFileChooser (new File ("."));

        fc.setApproveButtonText
            (App.getResources().getString("dialog.save.name"));
        fc.setApproveButtonMnemonic
            (App.getResources().getString("dialog.save.mnemonic").charAt(0));

        fc.setFileFilter(filter);

        if (fc.showDialog(parent, null) == JFileChooser.APPROVE_OPTION) {
            return fc.getSelectedFile();
        }
        return null;
    }

    // }}}

    //----------------------------------------------------------------------
    // A FileFilter implementation
    //----------------------------------------------------------------------
    // {{{ class LSFileFilter

    /**
     * A FileFilter that accepts directories and one type of log files.
     */
    private static class LSFileFilter extends FileFilter
    {
        /**
         * The file name extension to accept.
         */
        private String ext;

        // {{{ LSFileFilter

        /**
         * Create a new LSFileFilter.
         *
         * @param       ext     The file name extension to accept.
         */
        public LSFileFilter (String ext)
        {
            this.ext = ext;
        }

        // }}}
        // {{{ accept

        /**
         * Accept or reject a File.
         *
         * @param       file    The file to evaluate.
         *
         * @return      True if the file is a directory or has the required
         *              extension, false otherwise.
         */
        public boolean accept(File file)
        {
            return file.isDirectory() || file.getName().endsWith(ext);
        }

        // }}}
        // {{{ getDescription

        /**
         * Get a description for the type of file this FileFilter
         * accepts.
         *
         * @return      A description take from the application's resources.
         */
        public String getDescription()
        {
            return App.getResources().getString("fileDescFor" + ext);
        }

        // }}}
    }

    // }}}
}
