// {{{ copyright

/********************************************************************
 *
 * $Id: ViewTable.java,v 1.7 2000/07/05 14:07:43 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.apps.qflog;

// {{{ imports

import java.awt.Component;

import javax.swing.Icon;
import javax.swing.ImageIcon;
import javax.swing.JLabel;
import javax.swing.JTable;
import javax.swing.ListSelectionModel;
import javax.swing.event.TableModelEvent;
import javax.swing.table.DefaultTableCellRenderer;

import de.qfs.lib.gui.WholeRowFocusRenderer;
import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;

import de.qfs.apps.qflog.logview.LogView;

// }}}

/**
 * The table used to display the views. Just sets a few parameters and
 * uses a special renderer.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.7 $
 */
public class ViewTable extends JTable
{
    // {{{ variables

    /**
     * The Logger used for logging.
     */
    private final static Logger logger = new Logger (ViewTable.class);

    /**
     * The names of the icon resources.
     */
    private final static String iconNames[] = {
        "logView.icon.file",
        "logView.icon.connected",
        "logView.icon.disconnected"
    };

    /**
     * The icons to render.
     */
    private final static Icon[] icons = new Icon[iconNames.length];


    // }}}

    // {{{ ViewTable

    /**
     * Create a new ViewTable.
     *
     * @param   model   The ViewTableModel for the table.
     */
    public ViewTable (Model model)
    {
        super (model);
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "ViewTable(Model)",
                       logger.level < Log.MTDDETAIL ? "" :
                       "model: " + model);
        }

        initIcons();

        getSelectionModel().setSelectionMode
            (ListSelectionModel.SINGLE_SELECTION);
        setAutoResizeMode(JTable.AUTO_RESIZE_OFF);
        setShowVerticalLines(false);
        setShowHorizontalLines(false);
        Renderer renderer = new Renderer ();
        addFocusListener(renderer);
        setDefaultRenderer(Object.class, renderer);
        setDefaultRenderer(Integer.class, renderer);
        setDefaultRenderer(String.class, renderer);
        getColumnModel().setColumnMargin(0);
    }

    // }}}

    // {{{ getViewModel

    /**
     * Get the original ViewTableModel of the table.
     */
    //  public final Model getViewModel()
    //  {
        //  return viewModel;
    //  }

    // }}}
    // {{{ initIcons

    /**
     * Fetch the icons.
     */
    private void initIcons()
    {
        if (icons[0] == null) {
            for (int i = 0; i < icons.length; i++) {
                icons[i] = App.getResources().getIcon(iconNames[i], null);
            }
        }
    }

    // }}}
    // {{{ isManagingFocus

    /**
     * Signal no interest in internal focu management.
     *
     * @return  Always false.
     */
    public boolean isManagingFocus()
    {
        return false;
    }

    // }}}

    //----------------------------------------------------------------------
    // Renderer for the table.
    //----------------------------------------------------------------------
    // {{{ class Renderer

    /**
     * Cell renderer for the ViewTable.
     */
    private class Renderer extends WholeRowFocusRenderer
    {
        /**
         * Create a new Renderer.
         */
        public Renderer()
        {
            setStippleBorder();
        }

        /**
         * Get the Component to render the table cell. Sets the icon for
         * the state column.
         */
        public Component getTableCellRendererComponent
            (JTable table, Object value, boolean isSelected,
             boolean hasFocus, int row, int column) {
            JLabel label = (JLabel) super.getTableCellRendererComponent
                (table,value, isSelected, false, row, column);
            if (table.convertColumnIndexToModel(column) == Model.COL_STATE) {
                switch (((Integer) value).intValue()) {
                case LogView.STATE_FILE:
                    label.setIcon(icons[0]);
                    label.setText(null);
                    break;
                case LogView.STATE_CONNECTED:
                    label.setIcon(icons[1]);
                    label.setText(null);
                    break;
                case LogView.STATE_DISCONNECTED:
                    label.setIcon(icons[2]);
                    label.setText(null);
                    break;
                }
            } else {
                label.setIcon(null);
            }
            return label;
        }
    }

    // }}}
}
