// {{{ copyright

/********************************************************************
 *
 * $Id: CommandEditRemove.java,v 1.7 2000/07/05 14:07:44 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.apps.qflog.command;

// {{{ imports

import java.awt.Component;
import java.awt.Frame;

import javax.swing.JOptionPane;
import javax.swing.JTable;

import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;
import de.qfs.lib.command.CancelCommandException;
import de.qfs.lib.command.Command;
import de.qfs.lib.command.CommandException;
import de.qfs.lib.command.Invokable;
import de.qfs.lib.gui.FilteredAndSortedTableModel;
import de.qfs.lib.gui.Message;

import de.qfs.apps.qflog.logview.LogView;

import de.qfs.apps.qflog.Model;

// }}}

/**
 * This Command saves the log entries from the listener in the selected row of
 * the listener table into a log file.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.7 $
 */
public class CommandEditRemove extends Command
implements Invokable
{
    // {{{ variables

    /**
     * The Logger used for logging.
     */
    private final static Logger logger = new Logger (CommandEditRemove.class);

    /**
     * The parent Frame for the FileChooser.
     */
    private Frame parent;

    /**
     * The listener table.
     */
    private JTable table;

    // }}}

    // {{{ constructor

    /**
     * Create a new CommandEditRemove.
     *
     * @param   source  The source of the Command.
     * @param   parent  A frame parent for messages.
     * @param   table   The listener table.
     */
    public CommandEditRemove (Object source, Frame parent, JTable table)
    {
        super (source);
        this.parent = parent;
        this.table = table;
    }

    // }}}

    // {{{ invoke

    /**
     * Invoke the command.
     *
     * @return  Always null.
     *
     * @throws  CommandException        If the action is cancelled.
     */
    public Object invoke()
        throws CommandException
    {
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "invoke()", "");
        }

        int row = table.getSelectedRow();
        if (row == -1) {
            return null;
        }
        row = ((FilteredAndSortedTableModel) table.getModel())
            .getMappedRow(row);

        LogView view = Model.instance().getViewForRow(row);

        if (view.getState() == view.STATE_CONNECTED) {
            if (Message.showMessage(parent, "deleteConnected")
                != JOptionPane.OK_OPTION) {
                throw new CancelCommandException ();
            }
        }
        Model.instance().removeView(row);
        return null;
    }

    // }}}
}
