// {{{ copyright

/********************************************************************
 *
 * $Id: CommandFileExit.java,v 1.10 2000/07/05 14:07:44 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.apps.qflog.command;

// {{{ imports

import java.io.FileOutputStream;
import java.rmi.Naming;

import de.qfs.lib.command.Command;
import de.qfs.lib.command.CommandException;
import de.qfs.lib.command.Invokable;
import de.qfs.lib.config.Configuration;
import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;
import de.qfs.lib.logrmi.RemoteLogFilter;

import de.qfs.apps.qflog.App;

// }}}

/**
 * This Command exits the application, removing the server from the RMI
 * registry and saving the Configuration first.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.10 $
 */
public class CommandFileExit extends Command
implements Invokable
{
    // {{{ variables

    /**
     * The Logger used for logging.
     */
    private final static Logger logger = new Logger (CommandFileExit.class);


    // }}}

    // {{{ constructor

    /**
     * Create a new CommandFileExit.
     *
     * @param   source  The source of the Command.
     */
    public CommandFileExit (Object source)
    {
        super (source);
    }

    // }}}

    // {{{ invoke

    /**
     * Invoke the command.
     *
     * @return  Always null.
     *
     * @throws  CommandException        Never.
     */
    public Object invoke()
         throws CommandException
    {
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "invoke()", "");
        }

        // App.getCommandDistributor().assignCommandSilently
            // (new CommandMaybeSave (source));

        try {
            // save configuration
            FileOutputStream fos =
                new FileOutputStream (App.instance().getConfigFile());
            // VersionedSerializable.setSaving(true);
            Configuration.instance().save(fos);
            // VersionedSerializable.setSaving(false);
            fos.close();
            if (logger.level >= Log.MSG) {
                logger.log(Log.MSG, "invoke()",
                           "Configuration saved");
            }
            // remove RMI server
            Naming.unbind ("//"+ App.instance().getServerHost() +
                           "/" + App.instance().getServerName());
            if (logger.level >= Log.MSG) {
                logger.log(Log.MSG, "main(String[])",
                           "TestServer unbound");
            }
        } catch (Exception ex) {
            if (logger.level >= Log.ERR) {
                logger.log("invoke()", ex);
            }
        }
        Log.setQueueing(false);
        RemoteLogFilter.stopLogging();
        System.exit(0);

        // never reached
        return null;
    }

    // }}}
}
