// {{{ copyright

/********************************************************************
 *
 * $Id: CommandFileOpen.java,v 1.10 2000/07/05 14:07:44 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.apps.qflog.command;

// {{{ imports

import java.awt.Component;
import java.awt.Frame;

import java.io.File;

import de.qfs.lib.command.CancelCommandException;
import de.qfs.lib.command.Command;
import de.qfs.lib.command.CommandException;
import de.qfs.lib.command.Invokable;
import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;

import de.qfs.apps.qflog.App;
import de.qfs.apps.qflog.Model;

import de.qfs.apps.qflog.logview.LogView;
import de.qfs.apps.qflog.logview.command.CommandSaveLog;

// }}}

/**
 * This Command creates a new view for a LogFile.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.10 $
 */
public class CommandFileOpen extends Command
implements Invokable
{
    // {{{ variables

    /**
     * The Logger used for logging.
     */
    private final static Logger logger = new Logger (CommandFileOpen.class);

    /**
     * The parent Frame for the FileChooser.
     */
    private Frame parent;

    /**
     * The file to open.
     */
    private File file;

    // }}}

    // {{{ constructors

    /**
     * Create a new CommandFileOpen.
     *
     * @param   source  The source of the Command.
     * @param   parent  The parent Frame for the FileChooser.
     */
    public CommandFileOpen (Object source, Frame parent)
    {
        super (source);
        this.parent = parent;
    }

    /**
     * Create a new CommandFileOpen.
     *
     * @param   source  The source of the Command.
     * @param   parent  The parent Frame for the FileChooser - ignored.
     * @param   file    The file to open.
     */
    public CommandFileOpen (Object source, Frame parent, File file)
    {
        super (source);
        this.parent = parent;
        this.file = file;
    }

    // }}}

    // {{{ invoke

    /**
     * Invoke the command.
     *
     * @return  Always null.
     *
     * @throws  CommandException        Never.
     */
    public Object invoke()
         throws CommandException
    {
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "invoke()", "");
        }

        LogView view = new LogView ();
        view.setLoggingEnabled(true);
        //  view.getConfigurator().register();
        App.getCommandDistributor().assignCommandSilently
            (new CommandSaveLog (this, parent, view, file, false, false));

        Model.instance().addView(view);

        //  String name = view.getClientName();
        //  if (name == null) {
            //  name = "unknown";
        //  }
        //  int id = Model.instance().getNewId(name);

        //  try {
            //  LogListenerImpl listener =
                //  new LogListenerImpl (name, id, true, view);
        //  } catch (RemoteException ex) {
            //  // shouldn't happen
            //  if (logger.level >= Log.ERR) {
                //  logger.log("invoke()", ex);
            //  }
            //  return null;
        //  }

        //  if (file == null) {
            //  file = FileChooser.openLog(parent);
            //  if (file == null) {
                //  throw new CancelCommandException();
            //  }
        //  }

        //  String name = "unknown";
        //  try {
            //  ObjectInputStream ois = new ObjectInputStream
                //  (new FileInputStream (file));
            //  int version = ois.readInt();
            //  name = (String) ((Object[]) ois.readObject())[0];
            //  ois.close();
        //  } catch (Exception ex) {
            //  if (logger.level >= Log.MSG) {
                //  logger.log(Log.MSG, "invoke()", ex);
            //  }
        //  }
        //  int id = Model.instance().getNewId(name);
        //  try {
            //  LogListenerImpl listener =
                //  new LogListenerImpl (name, id, true);
        //  } catch (RemoteException ex) {
            //  if (logger.level >= Log.ERR) {
                //  logger.log("invoke()", ex);
            //  }
            //  return null;
        //  }
        //  App.getCommandDistributor().assignCommandSilently
            //  (new CommandSaveLog (this, parent,
                                 //  Model.instance().getTableModel()
                                 //  .getViewForListener(0), file,
                                 //  false, false));
        return null;
    }

    // }}}
}
