// {{{ copyright

/********************************************************************
 *
 * $Id: CommandHelpAbout.java,v 1.2 2000/07/05 14:07:44 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.apps.qflog.command;

// {{{ imports

import java.awt.Frame;

import de.qfs.lib.command.Command;
import de.qfs.lib.command.CommandException;
import de.qfs.lib.command.Invokable;
import de.qfs.lib.gui.Message;
import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;

import de.qfs.apps.qflog.App;
import de.qfs.apps.qflog.Version;

// }}}

/**
 * This command brings up a dialog displaying version and copyright
 * information.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.2 $
 */
public class CommandHelpAbout extends Command
implements Invokable
{
    // {{{ variables

    /**
     * The Logger used for logging.
     */
    private final static Logger logger = new Logger (CommandHelpAbout.class);

    /**
     * The parent for the dialog.
     */
    private Frame parent;

    // }}}

    // {{{ CommandHelpAbout

    /**
     * Create a new CommandHelpAbout.
     *
     * @param   source  The source of the Command.
     * @param   parent  The parent frame for the dialog.
     */
    public CommandHelpAbout (Object source, Frame parent)
    {
        super (source);
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "CommandHelpAbout(Object,Frame)", "");
        }
        this.parent = parent;
    }

    // }}}
    // {{{ invoke

    /**
     * Invoke the command.
     *
     * @return  Always null.
     *
     * @throws  CommandException        Never.
     */
    public Object invoke()
         throws CommandException
    {
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "invoke()", "");
        }

        Message.showMessage(parent, "qflog.info",
                            new String[] {Version.getVersion()});

        return null;
    }

    // }}}
}
