// {{{ copyright

/********************************************************************
 *
 * $Id: CommandOpenLogView.java,v 1.11 2000/07/05 14:07:44 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.apps.qflog.command;

// {{{ imports

import java.awt.Frame;

import javax.swing.JTable;
import javax.swing.SwingUtilities;

import de.qfs.lib.command.Command;
import de.qfs.lib.command.CommandException;
import de.qfs.lib.command.Invokable;
import de.qfs.lib.gui.FilteredAndSortedTableModel;
import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;

import de.qfs.apps.qflog.Model;

// }}}

/**
 * This Command opens a view for the listener in the selected row of the
 * listener table.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.11 $
 */
public class CommandOpenLogView extends Command
implements Invokable
{
    // {{{ variables

    /**
     * The Logger used for logging.
     */
    private final static Logger logger = new Logger (CommandOpenLogView.class);

    /**
     * The listener table.
     */
    private JTable table;

    /**
     * The row to take the listener from.
     */
    private int row = -1;

    // }}}

    // {{{ constructor

    /**
     * Create a new CommandOpenLogView.
     *
     * @param   source  The source of the Command.
     * @param   table   The view table.
     */
    public CommandOpenLogView (Object source, JTable table)

    {
        super (source);
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "CommandOpenLogView(Object,ViewTable)",
                       logger.level < Log.MTDDETAIL ? "" :
                       "source: " + source + ", " +
                       "table: " + table);
        }
        this.table = table;
    }

    /**
     * Create a new CommandOpenLogView.
     *
     * @param   source  The source of the Command.
     * @param   table   The view table.
     * @param   row     The row of the view.
     */
    public CommandOpenLogView (Object source, JTable table, int row)

    {
        super (source);
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "CommandOpenLogView(Object,ViewTable)",
                       logger.level < Log.MTDDETAIL ? "" :
                       "source: " + source + ", " +
                       "table: " + table);
        }
        this.table = table;
        this.row = row;
    }

    // }}}

    // {{{ invoke

    /**
     * Invoke the command.
     *
     * @return  Always null.
     *
     * @throws  CommandException        Never.
     */
    public Object invoke()
         throws CommandException
    {
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "invoke()", "");
        }

        if (row == -1) {
            row = table.getSelectedRow();
        }
        if (row >= 0) {
            row = ((FilteredAndSortedTableModel) table.getModel())
                .getMappedRow(row);
            final Frame frame =
                Model.instance().getFrameForRow(row);
            frame.show();
            frame.requestFocus();
        }
        return null;
    }

    // }}}
}
