// {{{ copyright

/********************************************************************
 *
 * $Id: FilterRootNode.java,v 1.6 2000/07/05 14:07:44 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.apps.qflog.logview;

import de.qfs.lib.gui.TreeNotification;

/**
 * Special FilterNode that knows about its model so it can pass on
 * notifications.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.6 $
 */
class FilterRootNode extends FilterNode
{
    /**
     * The model containing the node.
     */
    private LogFilterTreeModel model;

    // {{{ constructor

   /**
     * Create a new FilterRootNode.
     *
     * @param   clazz   The class of the node's data.
     * @param   method  The method of the node's data.
     * @param   model   The model containing the node.
     */
     public FilterRootNode (String clazz, String method,
                           LogFilterTreeModel model)
    {
        super (clazz, method);
        this.model = model;
    }

    // }}}

    // {{{ notify

    /**
     * Notify the node of some change. Passes the notification on to the model.
     *
     * @param   notification    Details of the change.
     */
    public void notify(TreeNotification notification)
    {
        notification.prependNode(this);
        if (model != null) {
            model.notify(notification);
        }
    }

    // }}}
}
