// {{{ copyright

/********************************************************************
 *
 * $Id: LogFileFilter.java,v 1.4 2000/07/05 14:07:44 gs Exp $
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 1999 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.apps.qflog.logview;

// {{{ imports

import java.io.File;
import javax.swing.filechooser.FileFilter;

// }}}

/**
 * File filter for log and configuration files.
 *
 * @author      Gregor Schmid
 * @version     $Revision: 1.4 $
 */
public class LogFileFilter
    extends FileFilter
{
    // {{{ variables

    /**
     * The description for the LogFileFilter.
     */
    private String desc;

    /**
     * The extensions to accept.
     */
    private String[] ext;

    // }}}

    // {{{ constructors

    /**
     * Create a new LogFileFilter.
     *
     * @param   desc    The description for the LogFileFilter.
     * @param   ext     The extension to accept.
     */
    public LogFileFilter (String desc, String ext)
    {
        this.ext = new String[] {ext};
        this.desc = desc;
    }

    /**
     * Create a new LogFileFilter.
     *
     * @param   desc    The description for the LogFileFilter.
     * @param   ext     The extensions to accept.
     */
    public LogFileFilter (String desc, String[] multi)
    {
        this.ext = multi;
        this.desc = desc;
    }

    // }}}

    // {{{ accept

    /**
     * Accept or reject a file.
     *
     * @param   file    The file to test.
     *
     * @return  True if the file's extension matches one of the
     *              LogFileFilter's extensions.
     */
    public boolean accept(File file)
    {
        if (file.isDirectory()) {
            return true;
        }
        for (int i = 0; i < ext.length; i++) {
            if (file.getName().endsWith(ext[i])) {
                return true;
            }
        }
        return false;
    }

    // }}}
    // {{{ getDescription

    /**
     * Get a description for the LogFileFilter.
     *
     * @return  The LogFileFilter's description.
     */
    public String getDescription()
    {
        return desc;
    }

    // }}}
    // {{{ forceExtension

    /**
     * Ensure that a file has the proper extension for the LogFileFilter.
     *
     * @param   file    The file to correct.
     *
     * @return  The correct file.
     */
    public File forceExtension(File file)
    {
        if (file.getName().endsWith(ext[0])) {
            return file;
        }
        return new File(file.getPath() + ext[0]);
    }

    // }}}
}
