# -*-makefile-*-

#------------------------------------------------------------------------------
# This file contains targets and definitions to compile Quality First
# Software products. You should NOT need to edit anything in this file.
# Edit makefile.system instead.
#------------------------------------------------------------------------------

ifdef BOOTCLASSPATH
CLASSPATH := $(BOOTCLASSPATH)$(PS).$(PS)$(CLASSPATH)
else
CLASSPATH := .$(PS)$(CLASSPATH)
endif

PACKAGENAMES = $(subst /,.,$(SRCDIRS))

# preprocess .jpp files to generate .java files
PRECOMP = $(foreach dir,$(SRCDIRS),$(wildcard $(dir)/*.jpp))
PREINT = $(patsubst %.jpp,%.java_$(JDK),$(PRECOMP))
PRETARGET = $(patsubst %.jpp,%.java,$(PRECOMP))

# java files to compile
COMP = $(foreach dir,$(SRCDIRS),$(wildcard $(dir)/*.java))

ifdef JCPP
# precompile using preprocessor
%.java_$(JDK) : %.jpp FORCE
	$(JCPP) $(CPPFLAGS) $< -o $@
.PRECIOUS: $(PREINT)
endif

# copy pregenerated file
%.java : %.java_$(JDK) FORCE
	cp $< $@
FORCE:

precompile: $(PRETARGET)
precompile_int: $(PREINT)
.PHONY: precompile_int
precompile_clean:
	for i in `find . -name \\*.jpp`; do \
	rm -f `dirname $$i`/`basename $$i .jpp`.java; done

# compile .java files to .class files
# call nested make to get correct expansion for $(COMP) including
# the precompiled files
compile:
	$(MAKE) _compile
_compile:
	$(JAVAC) -d $(CLASSES) -classpath '$(CLASSPATH)' $(COMP)
.PHONY: compile

# create RMI stubs and skeletons
rmi:
	$(RMIC) $(RMICFLAGS) -classpath '$(CLASSES)$(PS)$(CLASSPATH)' \
	-d $(CLASSES) $(RMI)

# copy resources
resources:
	for i in $(RESOURCES); do \
		cp -a $$i $(CLASSES)/`dirname $$i`; \
	done

# create the documentation
doc:
	$(JAVADOC) $(JAVADOCFLAGS) -d $(DOCDIR) -sourcepath . \
	-classpath "$(CLASSPATH)" $(PACKAGENAMES)
.PHONY: doc
